/*
*
*  This software was developed by the Thermal Modeling and Analysis
*  Project(TMAP) of the National Oceanographic and Atmospheric
*  Administration's (NOAA) Pacific Marine Environmental Lab(PMEL),
*  hereafter referred to as NOAA/PMEL/TMAP.
*
*  Access and use of this software shall impose the following
*  obligations and understandings on the user. The user is granted the
*  right, without any fee or cost, to use, copy, modify, alter, enhance
*  and distribute this software, and any derivative works thereof, and
*  its supporting documentation for any purpose whatsoever, provided
*  that this entire notice appears in all copies of the software,
*  derivative works and supporting documentation.  Further, the user
*  agrees to credit NOAA/PMEL/TMAP in any publications that result from
*  the use of this software or in any product that includes this
*  software. The names TMAP, NOAA and/or PMEL, however, may not be used
*  in any advertising or publicity to endorse or promote any products
*  or commercial entity unless specific written permission is obtained
*  from NOAA/PMEL/TMAP. The user also understands that NOAA/PMEL/TMAP
*  is not obligated to provide the user with any support, consulting,
*  training or assistance of any kind with regard to the use, operation
*  and performance of this software nor to provide the user with any
*  updates, revisions, new versions or "bug fixes".
*
*  THIS SOFTWARE IS PROVIDED BY NOAA/PMEL/TMAP "AS IS" AND ANY EXPRESS
*  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
*  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
*  ARE DISCLAIMED. IN NO EVENT SHALL NOAA/PMEL/TMAP BE LIABLE FOR ANY SPECIAL,
*  INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
*  RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
*  CONTRACT, NEGLIGENCE OR OTHER TORTUOUS ACTION, ARISING OUT OF OR IN
*  CONNECTION WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.  
*/

/* 
 * Return a float value from a character string
 *
 * v5.41 *kob*  3/02
 *
 * *acm*  3/05 v581 - return bad_value if input cannot be converted to numeric
 * *acm*  1/12      - Ferret 6.8 ifdef double_p for double-precision ferret, see the
 *                                       definition of macro DFTYPE in ferret.h.
 *
 */

#ifdef MAC_SSIZE
typedef long ssize_t;
#endif

#include <stdlib.h>
#include "ferret.h"

void c_strfloat_(in_ptr, out_ptr, bad_ptr)
     char** in_ptr;
     DFTYPE* out_ptr;
     DFTYPE* bad_ptr;
{
   double dval;
   char  *endptr;

   if ( *in_ptr == NULL ) {
      /* no string defined, so set to the bad value */
      *out_ptr = *bad_ptr;
      return;
   }

   dval = strtod(*in_ptr, &endptr);
   if ( endptr == *in_ptr ) {
      /* not numeric, so set to the bad value */
      *out_ptr = *bad_ptr;
   }
   else {
      *out_ptr = (DFTYPE) dval;
   }
}

