	SUBROUTINE BAD_EDGES( cx, x, mx )

*  This software was developed by the Thermal Modeling and Analysis
*  Project(TMAP) of the National Oceanographic and Atmospheric
*  Administration's (NOAA) Pacific Marine Environmental Lab(PMEL),
*  hereafter referred to as NOAA/PMEL/TMAP.
*
*  Access and use of this software shall impose the following
*  obligations and understandings on the user. The user is granted the
*  right, without any fee or cost, to use, copy, modify, alter, enhance
*  and distribute this software, and any derivative works thereof, and
*  its supporting documentation for any purpose whatsoever, provided
*  that this entire notice appears in all copies of the software,
*  derivative works and supporting documentation.  Further, the user
*  agrees to credit NOAA/PMEL/TMAP in any publications that result from
*  the use of this software or in any product that includes this
*  software. The names TMAP, NOAA and/or PMEL, however, may not be used
*  in any advertising or publicity to endorse or promote any products
*  or commercial entity unless specific written permission is obtained
*  from NOAA/PMEL/TMAP. The user also understands that NOAA/PMEL/TMAP
*  is not obligated to provide the user with any support, consulting,
*  training or assistance of any kind with regard to the use, operation
*  and performance of this software nor to provide the user with any
*  updates, revisions, new versions or "bug fixes".
*
*  THIS SOFTWARE IS PROVIDED BY NOAA/PMEL/TMAP "AS IS" AND ANY EXPRESS
*  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
*  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
*  ARE DISCLAIMED. IN NO EVENT SHALL NOAA/PMEL/TMAP BE LIABLE FOR ANY SPECIAL,
*  INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
*  RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
*  CONTRACT, NEGLIGENCE OR OTHER TORTUOUS ACTION, ARISING OUT OF OR IN
*  CONNECTION WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE. 
*
*
* context cx contains the limits of the valid data within array X
* fill the edges of array X with bad-data flags

* programmer - steve hankin
* NOAA/PMEL, Seattle, WA - Tropical Modeling and Analysis Program
* written for VAX computer under VMS operating system
*
* V200:   8/3/89
*	10/16/89 - modified array declarations via call to *_SUB
* V533: *sh* 6/01 - added string support
*       *acm* 3/12 Add E and F dimensions (use nferdims in tmap_dims.parm)

	include 'tmap_dims.parm'
	include 'ferret.parm'
	include	'xcontext.cmn'
	include	'xvariables.cmn'

* calling argument declarations:
	INTEGER cx, mx
	REAL    x( * )

* --- end of introductory code ---

	IF (mr_type(mx) .EQ. ptype_string) THEN
	   CALL BAD_PTR_EDGES_SUB( cx, x,
     .			    mr_lo_s1(mx), mr_hi_s1(mx),
     .			    mr_lo_s2(mx), mr_hi_s2(mx),
     .			    mr_lo_s3(mx), mr_hi_s3(mx),
     .			    mr_lo_s4(mx), mr_hi_s4(mx),
     .			    mr_lo_s5(mx), mr_hi_s5(mx),
     .			    mr_lo_s6(mx), mr_hi_s6(mx) )
	ELSE
	   CALL BAD_EDGES_SUB( cx, x,
     .			    mr_lo_s1(mx), mr_hi_s1(mx),
     .			    mr_lo_s2(mx), mr_hi_s2(mx),
     .			    mr_lo_s3(mx), mr_hi_s3(mx),
     .			    mr_lo_s4(mx), mr_hi_s4(mx),
     .			    mr_lo_s5(mx), mr_hi_s5(mx),
     .			    mr_lo_s6(mx), mr_hi_s6(mx),
     .			    mr_bad_data(mx) )
	ENDIF

	RETURN
	END 

